import iniconfig


def fly():
    pass


if __name__ == '__main__':
    print("Caw")
